###############################################################################
###############################################################################
##
##  Copyright (C) 2004-2005 Red Hat, Inc.  All rights reserved.
##
##  This copyrighted material is made available to anyone wishing to use,
##  modify, copy, or redistribute it subject to the terms and conditions
##  of the GNU General Public License v.2.
##
###############################################################################
###############################################################################
%define buildup 1
%define buildsmp 1
%define buildhugemem 1
%define buildlargesmp 1
%define buildxen 1
%define kernel_version 2.6.9-89.0.3.EL
%define subversion 10

%ifnarch i686 x86_64
%define buildsmp 0
%define buildxen 0
%endif

%ifnarch i686 
%define buildhugemem 0
%endif 


%ifnarch x86_64 ia64 ppc64
%define buildlargesmp 0
%endif

Name: gnbd-kernel
Version: 2.6.9
Release: %{subversion}.56%{?dist}.3
License: GPL
Group: System Environment/Kernel
Summary: gnbd-kernel - The kernel module for GFS's Network Block Device
BuildRequires: kernel-devel = %{kernel_version}
%if %{buildsmp}
BuildRequires: kernel-smp-devel = %{kernel_version}
%endif

%if %{buildhugemem}
BuildRequires: kernel-hugemem-devel = %{kernel_version}
%endif

%if %{buildlargesmp}
BuildRequires: kernel-largesmp-devel = %{kernel_version}
%endif

%if %{buildxen}
BuildRequires: kernel-xenU-devel = %{kernel_version}
%endif

Conflicts: GFS <= 6.0
Conflicts: GFS-modules
Requires: kernel = %{kernel_version}
Requires: /lib/modules/%{kernel_version}
Provides: gnbd-kernel-modules = %{version}-%{release}
Provides: kernel-modules
ExclusiveArch: i686 ia64 x86_64 ppc64
Source0: %{name}-%{version}-%{subversion}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
gnbd-kernel - The kernel module for GFS's Network Block Device

%package -n gnbd-kernheaders
Group: Development/System
Summary: gnbd kernel header files

%description -n gnbd-kernheaders
The gnbd kernel headers are used to compile the gnbd userland tools.

%if %{buildsmp}
%package -n gnbd-kernel-smp
Group: System Environment/Kernel
Summary: gnbd-kernel-smp - The kernel module for GFS's Network Block Device
Requires: kernel-smp = %{kernel_version}
Requires: /lib/modules/%{kernel_version}smp
Provides: gnbd-kernel-modules = %{version}-%{release}
Provides: kernel-modules

%description -n gnbd-kernel-smp
gnbd-kernel-smp - The smp kernel module for GFS's Network Block Device
%endif

%if %{buildhugemem}
%package -n gnbd-kernel-hugemem
Group: System Environment/Kernel
Summary: gnbd-kernel-hugemem - The kernel module for GFS's Network Block Device
Requires: kernel-hugemem = %{kernel_version}
Requires: /lib/modules/%{kernel_version}hugemem
Provides: gnbd-kernel-modules = %{version}-%{release}
Provides: kernel-modules

%description -n gnbd-kernel-hugemem
gnbd-kernel-hugemem - The hugemem kernel module for GFS's Network Block Device
%endif

%if %{buildlargesmp}
%package -n gnbd-kernel-largesmp
Group: System Environment/Kernel
Summary: gnbd-kernel-largesmp - The kernel module for GFS's Network Block Device
Requires: kernel-largesmp = %{kernel_version}
Requires: /lib/modules/%{kernel_version}largesmp
Provides: gnbd-kernel-modules = %{version}-%{release}
Provides: kernel-modules

%description -n gnbd-kernel-largesmp
gnbd-kernel-hugemem - The largesmp kernel module for GFS's Network Block Device
%endif

%if %{buildxen}
%package -n gnbd-kernel-xenU
Group: System Environment/Kernel
Summary: gnbd-kernel-xenU - The kernel module for GFS's Network Block Device
Requires: kernel-xenU = %{kernel_version}
Requires: /lib/modules/%{kernel_version}xenU
Provides: gnbd-kernel-modules = %{version}-%{release}
Provides: kernel-modules

%description -n gnbd-kernel-xenU
gnbd-kernel-hugemem - The xenU kernel module for GFS's Network Block Device
%endif
################################################################################
##  THE PREP SECTION
################################################################################
%prep
%setup -q -n %{name}-%{version}-%{subversion}

################################################################################
##  THE BUILD SECTION
################################################################################
%build
BUILD_TOPDIR=`pwd`
ROOT_DIR_FILES=`ls`

mkdir up
mv $ROOT_DIR_FILES up
cp -r up smp
cp -r up hugemem
cp -r up largesmp
cp -r up xenU

Build_gnbd(){
	cpu_type=$1
	flavor=$2
	kernel_src=/lib/modules/%{kernel_version}$flavor/build
	# Kernel tree setup
	if [ -d $kernel_src/. ]; then
		echo "Kernel %{kernel_version} found."
		echo $kernel_src
	else
		echo "Kernel %{kernel_version} not found."
		echo $kernel_src
		ls /lib/modules/*
		exit 1
	fi
        ./configure --kernel_src=$kernel_src --incdir=%{_includedir}
        make
}

%if %{buildup}
cd up
Build_gnbd %{_target_cpu}
cd ..
%endif

%if %{buildsmp}
cd smp
Build_gnbd %{_target_cpu} smp
cd ..
%endif

%if %{buildhugemem}
cd hugemem
Build_gnbd %{_target_cpu} hugemem
cd ..
%endif

%if %{buildlargesmp}
cd largesmp
Build_gnbd %{_target_cpu} largesmp
cd ..
%endif

%if %{buildxen}
cd xenU
Build_gnbd %{_target_cpu} xenU
cd ..
%endif

################################################################################
##  THE INSTALL SECTION
################################################################################
%install
rm -rf $RPM_BUILD_ROOT

%if %{buildup}
cd up
make install DESTDIR=$RPM_BUILD_ROOT
cd ..
%endif

%if %{buildsmp}
cd smp
make install DESTDIR=$RPM_BUILD_ROOT
cd ..
%endif

%if %{buildhugemem}
cd hugemem
make install DESTDIR=$RPM_BUILD_ROOT
cd ..
%endif

%if %{buildlargesmp}
cd largesmp
make install DESTDIR=$RPM_BUILD_ROOT
cd ..
%endif

%if %{buildxen}
cd xenU
make install DESTDIR=$RPM_BUILD_ROOT
cd ..
%endif


################################################################################
##  THE CLEAN SECTION
################################################################################
%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/depmod -e %{kernel_version}

%if %{buildsmp}
%post smp
/sbin/depmod -e %{kernel_version}smp
%endif

%if %{buildhugemem}
%post hugemem
/sbin/depmod -e %{kernel_version}hugemem
%endif

%if %{buildlargesmp}
%post largesmp
/sbin/depmod -e %{kernel_version}largesmp
%endif

%if %{buildxen}
%post xenU
/sbin/depmod -e %{kernel_version}xenU
%endif

%files
%defattr(-,root,root,-)
/lib/modules/%{kernel_version}/kernel/drivers/block/gnbd/gnbd.ko

%if %{buildsmp}
%files -n gnbd-kernel-smp
%defattr(-,root,root,-)
/lib/modules/%{kernel_version}smp/kernel/drivers/block/gnbd/gnbd.ko
%endif

%if %{buildhugemem}
%files -n gnbd-kernel-hugemem
%defattr(-,root,root,-)
/lib/modules/%{kernel_version}hugemem/kernel/drivers/block/gnbd/gnbd.ko
%endif

%if %{buildlargesmp}
%files -n gnbd-kernel-largesmp
%defattr(-,root,root,-)
/lib/modules/%{kernel_version}largesmp/kernel/drivers/block/gnbd/gnbd.ko
%endif

%if %{buildxen}
%files -n gnbd-kernel-xenU
%defattr(-,root,root,-)
/lib/modules/%{kernel_version}xenU/kernel/drivers/block/gnbd/gnbd.ko
%endif

%files -n gnbd-kernheaders
%defattr(-,root,root,-)
%{_includedir}/linux/gnbd.h

%changelog
* Wed Jul 08 2009 Chris Feist <cfeist@redhat.com>
- Build for kernel-2.6.9-89.0.3.EL
- Resolves: rhbz#510075

* Tue May 05 2009 Chris Feist <cfeist@redhat.com>
- Built for kernel-2.6.9-89.EL

* Thu Nov 08 2007 Chris Feist <cfeist@redhat.com>
- Built for 2.6.9-67.EL kernel

* Mon Aug 20 2007 Chris Feist <cfeist@redhat.com>
- Disable xen until kernel is fixed
- Built for 2.6.9-56.EL

* Mon Dec 04 2006 Chris Feist <cfeist@redhat.com>
- Added support for xenU kernel.

* Fri Jan 27 2006 Chris Feist <cfeiset@redhat.com>
- Added support for largesmp kernel.

* Tue May 17 2005 Chris Feist <cfeist@redhat.com>
- Provides gnbd-kernel-modules.

* Mon May 16 2005 Chris Feist <cfeist@redhat.com>
- Add depmod in %post scriplet.

* Fri May 06 2005 Chris Feist <cfeist@redhat.com>
- Cleanup .spec file.  Don't include file globs anymore.

* Mon Dec 20 2004 Chris Feist <cfeist@redhat.com>
- Rebuild for new kernel.

* Fri Dec 10 2004 Chris Feist <cfeist@redhat.com>
- Rebuild for new kernel.

* Thu Nov 18 2004 Chris Feist <cfeist@redhat.com>
- various bug fixes (new upstream sources)

* Mon Oct 25 2004 Chris Feist <cfeist@redhat.com>
- various bug fixes (new upstream sources)

* Tue Aug 17 2004 Jon Brassow <jbrassow@redhat.com>
- various bug fixes (new upstream sources)
- building smp modules, but not packaging them (fixed)

* Thu Jun 17 2004 Jon Brassow <jbrassow@redhat.com> 
- Initial build.
